fn broadcast_key<FEN: FoundryEvmNetwork>(
ccx: &mut CheatsCtxt<'_, '_, FEN>,
private_key: &U256,
single_call: bool,
) -> ResultExpand description
Sets up broadcasting from a script with the sender derived from private_key.
Adds this private key to state’s wallets vector to later be used for signing
if broadcast is successful.