fn broadcast_key<CTX: ContextTr<Journal: JournalExt, Db: DatabaseExt>>(
ccx: &mut CheatsCtxt<'_, CTX>,
private_key: &U256,
single_call: bool,
) -> ResultExpand description
Sets up broadcasting from a script with the sender derived from private_key.
Adds this private key to state’s wallets vector to later be used for signing
if broadcast is successful.